==> haskell-http-common-0.8.2.0-23-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-http-common.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: http-common
version: 0.8.2.0
id: http-common-0.8.2.0-1Ixdj2BB1dmDo5xPOv7bAl
key: http-common-0.8.2.0-1Ixdj2BB1dmDo5xPOv7bAl
license: BSD-3-Clause
copyright: © 2012-2015 Operational Dynamics Consulting, Pty Ltd and Others
maintainer: Andrew Cowie <andrew@operationaldynamics.com>
author: Andrew Cowie <andrew@operationaldynamics.com>
stability: experimental
homepage: http://research.operationaldynamics.com/projects/http-streams/
synopsis: Common types for HTTP clients and servers
description:
    /Overview/
    .
    Base types used by a variety of HTTP clients and servers. See http-streams
    "Network.Http.Client" or pipes-http "Pipes.Http.Client" for full
    documentation. You can import @Network.Http.Types@ if you like, but both
    http-streams and pipes-http re-export this package'\''s types and functions.
category: Web
abi: 43f21550ab6dfc27c4da98a6f0332c95
exposed: True
exposed-modules:
    Network.Http.Internal Network.Http.RequestBuilder
    Network.Http.Types
import-dirs: /usr/lib/ghc-8.4.3/site-local/http-common-0.8.2.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/http-common-0.8.2.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/http-common-0.8.2.0
hs-libraries: HShttp-common-0.8.2.0-1Ixdj2BB1dmDo5xPOv7bAl
depends:
    base-4.11.1.0 directory-1.3.1.5
    base64-bytestring-1.0.0.1-4OCIe2BZn8jKI191JIXI37
    blaze-builder-0.4.1.0-Gz7BwSYlOrTDOutVN7e028 bytestring-0.10.8.2
    case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra mtl-2.2.2
    transformers-0.5.5.0 network-2.7.0.2-CxFtLVxZlCwGfUj2kt7Tsu
    text-1.2.3.0 unordered-containers-0.2.9.0-HkLL4IW6wFT9NZ9Hv37TSa
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             directory-1.3.1.5=f5fa3aef63d61d9b32ef25d211ef137f
             base64-bytestring-1.0.0.1-4OCIe2BZn8jKI191JIXI37=65adc4f5f54a1c07291b4ebc49756c05
             blaze-builder-0.4.1.0-Gz7BwSYlOrTDOutVN7e028=f952a1ec5abae3e4435518edbfd82e4e
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra=0a5994e39a32f328ff4f350b25844411
             mtl-2.2.2=0b3b35c3b96c7607606ed10087c4aa4a
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
             network-2.7.0.2-CxFtLVxZlCwGfUj2kt7Tsu=43a70846fe67ebce9998ba267f800e6d
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             unordered-containers-0.2.9.0-HkLL4IW6wFT9NZ9Hv37TSa=81e1d2b217f05c2ba43642acf6d96f3b
haddock-interfaces: /usr/share/doc/haskell-http-common/html/http-common.haddock
haddock-html: /usr/share/doc/haskell-http-common/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-http-common-0.8.2.0-24-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-http-common.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: http-common
version: 0.8.2.0
id: http-common-0.8.2.0-2JbFpEHPVJPIEgp7t8cUZB
key: http-common-0.8.2.0-2JbFpEHPVJPIEgp7t8cUZB
license: BSD-3-Clause
copyright: © 2012-2015 Operational Dynamics Consulting, Pty Ltd and Others
maintainer: Andrew Cowie <andrew@operationaldynamics.com>
author: Andrew Cowie <andrew@operationaldynamics.com>
stability: experimental
homepage: http://research.operationaldynamics.com/projects/http-streams/
synopsis: Common types for HTTP clients and servers
description:
    /Overview/
    .
    Base types used by a variety of HTTP clients and servers. See http-streams
    "Network.Http.Client" or pipes-http "Pipes.Http.Client" for full
    documentation. You can import @Network.Http.Types@ if you like, but both
    http-streams and pipes-http re-export this package'\''s types and functions.
category: Web
abi: ab53cb86167686aeb27bcb3c29b1712a
exposed: True
exposed-modules:
    Network.Http.Internal Network.Http.RequestBuilder
    Network.Http.Types
import-dirs: /usr/lib/ghc-8.4.3/site-local/http-common-0.8.2.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/http-common-0.8.2.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/http-common-0.8.2.0
hs-libraries: HShttp-common-0.8.2.0-2JbFpEHPVJPIEgp7t8cUZB
depends:
    base-4.11.1.0 directory-1.3.1.5
    base64-bytestring-1.0.0.1-4OCIe2BZn8jKI191JIXI37
    blaze-builder-0.4.1.0-Gz7BwSYlOrTDOutVN7e028 bytestring-0.10.8.2
    case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra mtl-2.2.2
    transformers-0.5.5.0 network-2.7.0.2-CxFtLVxZlCwGfUj2kt7Tsu
    text-1.2.3.0 unordered-containers-0.2.9.0-KPgljVKoY3VBKTw1tFbcre
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             directory-1.3.1.5=f5fa3aef63d61d9b32ef25d211ef137f
             base64-bytestring-1.0.0.1-4OCIe2BZn8jKI191JIXI37=65adc4f5f54a1c07291b4ebc49756c05
             blaze-builder-0.4.1.0-Gz7BwSYlOrTDOutVN7e028=f952a1ec5abae3e4435518edbfd82e4e
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra=0a5994e39a32f328ff4f350b25844411
             mtl-2.2.2=0b3b35c3b96c7607606ed10087c4aa4a
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
             network-2.7.0.2-CxFtLVxZlCwGfUj2kt7Tsu=43a70846fe67ebce9998ba267f800e6d
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             unordered-containers-0.2.9.0-KPgljVKoY3VBKTw1tFbcre=264f905ec4c04eb05b5ff3d7321fae90
haddock-interfaces: /usr/share/doc/haskell-http-common/html/http-common.haddock
haddock-html: /usr/share/doc/haskell-http-common/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
